==> nosmsd-0.20.tar.gz: nosmsd-0.20/nosmsd/database.py <==
#!/usr/bin/env python
# encoding=utf-8

import peewee
from datetime import datetime

from nosmsd.settings import settings as nosettings
from nosmsd.utils import send_sms


def get_db_class(dbtype):
    return eval('peewee.%sDatabase' % dbtype)

db_adapter = get_db_class(nosettings.NOSMSD_DATABASE['type'])
dbh = db_adapter(nosettings.NOSMSD_DATABASE['name'],
                 **nosettings.NOSMSD_DATABASE_OPTIONS)


class BaseModel(peewee.Model):

    class Meta:
        database = dbh


class Inbox(BaseModel):

    class Meta:
        db_table = 'inbox'

    NO_COMP = 'Default_No_Compression'
    NO_COMP_UNI = 'Unicode_No_Compression'
    HEIGHTB = '8bit'
    COMP = 'Default_Compression'
    COMP_UNI = 'Unicode_Compression'
    CODINGS = (NO_COMP, NO_COMP_UNI, HEIGHTB, COMP, COMP_UNI)
    DEFAULT_CODING = NO_COMP

    STATUS_CREATED = 'created'
    STATUS_PROCESSED = 'processed'
    STATUS_ERROR = 'error'

    PROC_TRUE = 'true'
    PROC_FALSE = 'false'

    UpdatedInDB = peewee.DateTimeField()
    ReceivingDateTime = peewee.DateTimeField()
    Text = peewee.TextField()
    SenderNumber = peewee.CharField(max_length=20)
    Coding = peewee.CharField(max_length=50)
    UDH = peewee.TextField()
    SMSCNumber = peewee.CharField(max_length=20)
    Class = peewee.IntegerField()
    TextDecoded = peewee.TextField()
    ID = peewee.PrimaryKeyField()
    RecipientID = peewee.TextField()
    Processed = peewee.CharField(max_length=50)
    status = peewee.CharField(db_index=True, max_length=50)

    @property
    def content(self):
        return Inbox.multipart_text(self)

    @property
    def udh_root(self):
        if not self.UDH:
            return ''
        return self.UDH[:-2]

    @property
    def SequencePosition(self):
        try:
            return int(self.UDH[-2:])
        except:
            return 0

    def is_multipart(self):
        return bool(len(self.UDH))

    def parts(self):
        return Inbox.parts_from(self)

    @classmethod
    def parts_from(cls, message):
        parts = {}
        peers = Inbox.filter(SenderNumber=message.SenderNumber,
                             UDH__contains=message.udh_root)
        for peer in peers:
            # UDH colision?
            if not peer.UDH.startswith(message.udh_root):
                continue
            parts[peer.SequencePosition] = peer

        return parts

    @classmethod
    def multipart_text(cls, message):
        if message.is_multipart():
            return u''.join([p.TextDecoded
                             for p in cls.parts_from(message).values()])
        return message.TextDecoded

    def change_status(self, new_status, cascade=True):
        if not new_status in (self.STATUS_CREATED,
                              self.STATUS_PROCESSED,
                              self.STATUS_ERROR):
            return False
        if new_status == self.STATUS_CREATED:
            self.Processed = self.PROC_FALSE
        else:
            self.Processed = self.PROC_TRUE
        self.status = new_status
        self.save()
        if cascade and self.is_multipart():
            for part in self.parts():
                part.change_status(new_status, cascade=False)
        return True

    def mark_processed(self, cascade=True):
        self.change_status(self.STATUS_PROCESSED)

    def mark_error(self, cascade=True):
        self.change_status(self.STATUS_ERROR)

    def unmark_processed(self, cascade=True):
        self.change_status(self.STATUS_CREATED)

    @property
    def identity(self):
        return self.SenderNumber

    @property
    def is_hw_processed(self):
        return self.Processed == self.PROC_TRUE

    @property
    def is_processed(self):
        return self.status == self.STATUS_PROCESSED

    @property
    def is_error(self):
        return self.status == self.STATUS_ERROR

    @property
    def id(self):
        return self.ID

    @property
    def date(self):
        return self.ReceivingDateTime

    def respond(self, text):
        return send_sms(self.SenderNumber, text)

    @classmethod
    def from_id(cls, id_):
        return cls.filter(ID=id_).get()

    @classmethod
    def from_identity(cls, ident):
        return cls.filter(SenderNumber=ident)

    @classmethod
    def add(cls, sender, text):

        from nosmsd.utils import msg_is_unicode

        coding = cls.NO_COMP_UNI if msg_is_unicode(text) else cls.NO_COMP
        instance = cls(TextDecoded=text,
                       SenderNumber=sender,
                       status=cls.STATUS_CREATED,
                       Coding=coding,
                       Processed=Inbox.PROC_FALSE,
                       UpdatedInDB=datetime.now(),
                       ReceivingDateTime=datetime.now(),
                       Text=u'',
                       UDH=u'',
                       RecipientID=u'')
        instance.save()
        return instance

    def __unicode__(self):
        return u"%d#%s#%s" % (self.id, self.identity,
                              self.date.strftime('%d-%m-%Y'))

    def __repr__(self):
        return self.id


class Outbox(BaseModel):

    """ Do not use this model as it holds temporary data for gammu """

    class Meta:
        db_table = 'outbox'

    #ID = peewee.PrimaryKeyField()

    UpdatedInDB = peewee.DateTimeField()
    InsertIntoDB = peewee.DateTimeField()
    SendingDateTime = peewee.DateTimeField()
    SendBefore = peewee.DateTimeField()
    SendAfter = peewee.DateTimeField()
    Text = peewee.TextField()
    DestinationNumber = peewee.CharField()
    Coding = peewee.CharField('Default_No_Compression')
    UDH = peewee.CharField()
    Class = peewee.CharField('-1')
    TextDecoded = peewee.TextField(default=u'')
    ID = peewee.IntegerField()
    MultiPart = peewee.CharField(default='false')
    RelativeValidity = peewee.IntegerField(default=-1)
    SenderID = peewee.TextField(),
    SendingTimeOut = peewee.DateTimeField()
    DeliveryReport = peewee.CharField('default')
    CreatorID = peewee.CharField(null=True)


class OutBoxMultipart(BaseModel):

    class Meta:
        db_table = 'outbox_multipart'

    Text = peewee.TextField()
    Coding = peewee.CharField(default='Default_No_Compression')
    UDH = peewee.CharField()
    Class = peewee.IntegerField(default=-1)
    TextDecoded = peewee.TextField(null=True)
    ID = peewee.IntegerField()
    SequencePosition = peewee.IntegerField(default=1)


class SentItems(BaseModel):

    class Meta:
        db_table = 'sentitems'

    NO_COMP = 'Default_No_Compression'
    NO_COMP_UNI = 'Unicode_No_Compression'
    HEIGHTB = '8bit'
    COMP = 'Default_Compression'
    COMP_UNI = 'Unicode_Compression'
    CODINGS = (NO_COMP, NO_COMP_UNI, HEIGHTB, COMP, COMP_UNI)
    DEFAULT_CODING = NO_COMP

    STATUS_SENDING_OK = 'SendingOK'
    STATUS_SENDING_OK_NOREPORT = 'SendingOKNoReport'
    STATUS_SENDING_ERROR = 'SendingError'
    STATUS_DELIVERY_OK = 'DeliveryOK'
    STATUS_DELIVERY_FAILED = 'DeliveryFailed'
    STATUS_DELIVERY_PENDING = 'DeliveryPending'
    STATUS_DELIVERY_UNKNOWN = 'DeliveryUnknown'
    STATUS_ERROR = 'Error'

    UpdatedInDB = peewee.DateTimeField()
    InsertIntoDB = peewee.DateTimeField()
    SendingDateTime = peewee.DateTimeField()
    DeliveryDateTime = peewee.DateTimeField()
    Text = peewee.TextField()
    DestinationNumber = peewee.CharField(max_length=20)
    Coding = peewee.CharField()
    UDH = peewee.TextField()
    SMSCNumber = peewee.CharField(max_length=20)
    Class = peewee.IntegerField()
    TextDecoded = peewee.TextField()
    ID = peewee.PrimaryKeyField()
    SenderID = peewee.CharField(max_length=255)
    SequencePosition = peewee.PrimaryKeyField()
    Status = peewee.CharField()
    StatusError = peewee.IntegerField()
    TPMR = peewee.IntegerField()
    RelativeValidity = peewee.IntegerField()
    CreatorID = peewee.TextField()

    @property
    def content(self):
        return self.TextDecoded

    @property
    def identity(self):
        return self.DestinationNumber

    @property
    def is_error(self):
        return self.status == self.STATUS_ERROR

    @property
    def id(self):
        return self.ID

    @property
    def date(self):
        return self.SendingDateTime

==> nosmsd-0.24.tar.gz: nosmsd-0.24/nosmsd/database.py <==
#!/usr/bin/env python
# encoding=utf-8

import peewee
from datetime import datetime

from nosmsd.settings import settings as nosettings
from nosmsd.utils import send_sms


def get_db_class(dbtype):
    return eval('peewee.%sDatabase' % dbtype)

db_adapter = get_db_class(nosettings.NOSMSD_DATABASE['type'])
dbh = db_adapter(nosettings.NOSMSD_DATABASE['name'],
                 **nosettings.NOSMSD_DATABASE_OPTIONS)


class BaseModel(peewee.Model):

    class Meta:
        database = dbh


class Inbox(BaseModel):

    class Meta:
        db_table = 'inbox'

    NO_COMP = 'Default_No_Compression'
    NO_COMP_UNI = 'Unicode_No_Compression'
    HEIGHTB = '8bit'
    COMP = 'Default_Compression'
    COMP_UNI = 'Unicode_Compression'
    CODINGS = (NO_COMP, NO_COMP_UNI, HEIGHTB, COMP, COMP_UNI)
    DEFAULT_CODING = NO_COMP

    STATUS_CREATED = 'created'
    STATUS_PROCESSED = 'processed'
    STATUS_ERROR = 'error'

    PROC_TRUE = 'true'
    PROC_FALSE = 'false'

    UpdatedInDB = peewee.DateTimeField()
    ReceivingDateTime = peewee.DateTimeField()
    Text = peewee.TextField()
    SenderNumber = peewee.CharField(max_length=20)
    Coding = peewee.CharField(max_length=50)
    UDH = peewee.TextField()
    SMSCNumber = peewee.CharField(max_length=20)
    Class = peewee.IntegerField()
    TextDecoded = peewee.TextField()
    ID = peewee.PrimaryKeyField()
    RecipientID = peewee.TextField()
    Processed = peewee.CharField(max_length=50)
    status = peewee.CharField(db_index=True, max_length=50)

    @property
    def content(self):
        return Inbox.multipart_text(self)

    @property
    def udh_root(self):
        if not self.UDH:
            return ''
        return self.UDH[:-2]

    @property
    def SequencePosition(self):
        try:
            return int(self.UDH[-2:])
        except:
            return 0

    def is_multipart(self):
        return bool(len(self.UDH))

    def parts(self):
        return Inbox.parts_from(self)

    @classmethod
    def parts_from(cls, message):
        parts = {}
        peers = Inbox.select().where(Inbox.SenderNumber 
                                     == message.SenderNumber, 
                                     Inbox.UDH % message.udh_root)
        for peer in peers:
            # UDH colision?
            if not peer.UDH.startswith(message.udh_root):
                continue
            parts[peer.SequencePosition] = peer

        return parts

    @classmethod
    def multipart_text(cls, message):
        if message.is_multipart():
            return u''.join([p.TextDecoded
                             for p in cls.parts_from(message).values()])
        return message.TextDecoded

    def change_status(self, new_status, cascade=True):
        if not new_status in (self.STATUS_CREATED,
                              self.STATUS_PROCESSED,
                              self.STATUS_ERROR):
            return False
        if new_status == self.STATUS_CREATED:
            self.Processed = self.PROC_FALSE
        else:
            self.Processed = self.PROC_TRUE
        self.status = new_status
        self.save()
        if cascade and self.is_multipart():
            for part in self.parts():
                part.change_status(new_status, cascade=False)
        return True

    def mark_processed(self, cascade=True):
        self.change_status(self.STATUS_PROCESSED)

    def mark_error(self, cascade=True):
        self.change_status(self.STATUS_ERROR)

    def unmark_processed(self, cascade=True):
        self.change_status(self.STATUS_CREATED)

    @property
    def identity(self):
        return self.SenderNumber

    @property
    def is_hw_processed(self):
        return self.Processed == self.PROC_TRUE

    @property
    def is_processed(self):
        return self.status == self.STATUS_PROCESSED

    @property
    def is_error(self):
        return self.status == self.STATUS_ERROR

    @property
    def id(self):
        return self.ID

    @property
    def date(self):
        return self.ReceivingDateTime

    def respond(self, text):
        return send_sms(self.SenderNumber, text)

    @classmethod
    def from_id(cls, id_):
        return cls.filter(ID=id_).get()

    @classmethod
    def from_identity(cls, ident):
        return cls.filter(SenderNumber=ident)

    @classmethod
    def add(cls, sender, text):

        from nosmsd.utils import msg_is_unicode

        coding = cls.NO_COMP_UNI if msg_is_unicode(text) else cls.NO_COMP
        instance = cls(TextDecoded=text,
                       SenderNumber=sender,
                       status=cls.STATUS_CREATED,
                       Coding=coding,
                       Processed=Inbox.PROC_FALSE,
                       UpdatedInDB=datetime.now(),
                       ReceivingDateTime=datetime.now(),
                       Text=u'',
                       UDH=u'',
                       RecipientID=u'')
        instance.save()
        return instance

    def __unicode__(self):
        return u"%d#%s#%s" % (self.id, self.identity,
                              self.date.strftime('%d-%m-%Y'))

    def __repr__(self):
        return self.id


class Outbox(BaseModel):

    """ Do not use this model as it holds temporary data for gammu """

    class Meta:
        db_table = 'outbox'

    #ID = peewee.PrimaryKeyField()

    UpdatedInDB = peewee.DateTimeField()
    InsertIntoDB = peewee.DateTimeField()
    SendingDateTime = peewee.DateTimeField()
    SendBefore = peewee.DateTimeField()
    SendAfter = peewee.DateTimeField()
    Text = peewee.TextField()
    DestinationNumber = peewee.CharField()
    Coding = peewee.CharField('Default_No_Compression')
    UDH = peewee.CharField()
    Class = peewee.CharField('-1')
    TextDecoded = peewee.TextField(default=u'')
    ID = peewee.IntegerField()
    MultiPart = peewee.CharField(default='false')
    RelativeValidity = peewee.IntegerField(default=-1)
    SenderID = peewee.TextField(),
    SendingTimeOut = peewee.DateTimeField()
    DeliveryReport = peewee.CharField('default')
    CreatorID = peewee.CharField(null=True)


class OutBoxMultipart(BaseModel):

    class Meta:
        db_table = 'outbox_multipart'

    Text = peewee.TextField()
    Coding = peewee.CharField(default='Default_No_Compression')
    UDH = peewee.CharField()
    Class = peewee.IntegerField(default=-1)
    TextDecoded = peewee.TextField(null=True)
    ID = peewee.IntegerField()
    SequencePosition = peewee.IntegerField(default=1)


class SentItems(BaseModel):

    class Meta:
        db_table = 'sentitems'

    NO_COMP = 'Default_No_Compression'
    NO_COMP_UNI = 'Unicode_No_Compression'
    HEIGHTB = '8bit'
    COMP = 'Default_Compression'
    COMP_UNI = 'Unicode_Compression'
    CODINGS = (NO_COMP, NO_COMP_UNI, HEIGHTB, COMP, COMP_UNI)
    DEFAULT_CODING = NO_COMP

    STATUS_SENDING_OK = 'SendingOK'
    STATUS_SENDING_OK_NOREPORT = 'SendingOKNoReport'
    STATUS_SENDING_ERROR = 'SendingError'
    STATUS_DELIVERY_OK = 'DeliveryOK'
    STATUS_DELIVERY_FAILED = 'DeliveryFailed'
    STATUS_DELIVERY_PENDING = 'DeliveryPending'
    STATUS_DELIVERY_UNKNOWN = 'DeliveryUnknown'
    STATUS_ERROR = 'Error'

    UpdatedInDB = peewee.DateTimeField()
    InsertIntoDB = peewee.DateTimeField()
    SendingDateTime = peewee.DateTimeField()
    DeliveryDateTime = peewee.DateTimeField()
    Text = peewee.TextField()
    DestinationNumber = peewee.CharField(max_length=20)
    Coding = peewee.CharField()
    UDH = peewee.TextField()
    SMSCNumber = peewee.CharField(max_length=20)
    Class = peewee.IntegerField()
    TextDecoded = peewee.TextField()
    ID = peewee.PrimaryKeyField()
    SenderID = peewee.CharField(max_length=255)
    SequencePosition = peewee.PrimaryKeyField()
    Status = peewee.CharField()
    StatusError = peewee.IntegerField()
    TPMR = peewee.IntegerField()
    RelativeValidity = peewee.IntegerField()
    CreatorID = peewee.TextField()

    @property
    def content(self):
        return self.TextDecoded

    @property
    def identity(self):
        return self.DestinationNumber

    @property
    def is_error(self):
        return self.status == self.STATUS_ERROR

    @property
    def id(self):
        return self.ID

    @property
    def date(self):
        return self.SendingDateTime
